@PATH Selector
Date: 07 25, 2001 9:22:55 AM

# PATH Selector

The PATH Selector lets you specify a path of node names that must start with _ROOT, the root of the parse tree. The path specifies the root, its child, grandchild, and so on. The selection algorithm traverses the parse tree starting at the root and searches for a context node that matches the entire path. The phrase immediately under such a context node will be traversed to look for rule matches. (PATH does not check the unsealed flag.)

## See Also

Context Zone

SELECT Region

MULTI Selector

NODES Selector